/*
  This file is part of the Nepomuk KDE project.
  Copyright (C) 2010 Sebastian Trueg <trueg@kde.org>

  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) version 3, or any
  later version accepted by the membership of KDE e.V. (or its
  successor approved by the membership of KDE e.V.), which shall
  act as a proxy defined in Section 6 of version 3 of the license.

  This library is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef NEPOMUK_GUIITEMRESOURCEMODEL_H
#define NEPOMUK_GUIITEMRESOURCEMODEL_H

#include "resourcemodel.h"


namespace Nepomuk {
    /**
     * A ResourceModel that can read additional fields from
     * ResourceGuiItems.
     */
    class GuiItemResourceModel : public Nepomuk::ResourceModel
    {
        Q_OBJECT

    public:
        GuiItemResourceModel( QObject* parent = 0 );
        virtual ~GuiItemResourceModel();

        enum GuiItemResourceRoles
        {
            /**
             * The gui item itself as a pointer to AbstractResourceGuiItem.
             * This is used in the ResourceDelegate to retrieve the actual
             * item that will do the painting.
             */
            ResourceGuiItemRole = 986558
        };

        virtual QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;

    private:
        class Private;
        Private* const d;

        Q_PRIVATE_SLOT( d, void _k_dataChanged( const QUrl& ) )
    };
}

#endif
