/*
   Copyright (C) 2009 by Charles Wautier <charles.wautier@gmail.com>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

#ifndef _KRESOURCETREEVIEW_H_
#define _KRESOURCETREEVIEW_H_

#include <kfiletreeview.h>

#include "nepomuktasks_export.h"

/**
 * Convinience view for tasks trees, as defined by the tasks kioslave protocol
 */
class NEPOMUKTASKS_EXPORT KResourceTreeView : public KFileTreeView
{

    Q_OBJECT

public:

    KResourceTreeView(QWidget* parent);

    /**
     * Return the selected task-resource nepomuk-uri
     * ( Deduced from its Url )
     */
    KUrl selectedUri() const;

    /**
     * Return the current task-resource nepomuk-Uri
     * ( Deduced from its Url )
     */
    KUrl currentUri() const;

    /**
     * Set the root URL
     */
    void setRootUrl(const KUrl& url);

    /**
     * Build and set the root URL :
     * typeClass           uri of the class-resource that represents nodes of the tree ( role of the classic folders )
     * superProperty       uri of the property-resource that represents parent-node - son-node relation ( folder - folder relation )
     * linkProperty        uri of the property-resource that represents node - linked-resources relation ( folder - file relation )
     * bool                do we considerate sub classes or property
     * baseUrl             the base url without the protocol (which is automaticaly added)
     */
    void setRootUrl(const KUrl& typeClass, const KUrl& superProperty, const KUrl& linkProperty,
                    bool typeInheritance = false, bool superInheritance = false, bool linkInheritance = false,
                    const KUrl& baseUrl = KUrl());

Q_SIGNALS:

    /**
     * This signal is emitted whenever an @p url has been activated.
     */
    void activatedUri(const KUrl &url);

    /**
     * This signal is emitted whenever the current @p url has been changed.
     */
    void currentUriChanged(const KUrl &url) const;

private Q_SLOTS:

    void slotInit(const QString&);

    void proxy_currentChanged(const KUrl& url) const;

private:

    /**
     * Return :
     * - Empty KUrl if protocol is wrong (!= nepomuktree) or no resource is available at the url
     * - Uri of the resource otherwise
     */
    KUrl urlToUri(const KUrl& url) const;

    void init();
};

#endif
