/*
 * This file is part of the Nepomuk KDE project.
 * Copyright (C) 2008 Adrien Bustany <madcat@mymadcat.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef PEOPLETAGWIDGET_H
#define PEOPLETAGWIDGET_H

#include <QtGui>
#include <soprano/soprano.h>

namespace Ui { class Interface; }

namespace Nepomuk {

class LinkedPeopleModel;
class PeopleModel;
class OtherPersonDialog;
class FilterModel;
class ImageMarquee;
class Marquee;
class NepomukProxy;

/**
 * \class PeopleTagWidget peopletagwidget.h PeopleTagWidget
 *
 * \brief The PeopleTagWidget allows the user to link people and pictures. People
 * are searched in Nepomuk.
 *
 * This widget uses the NCO ontology, a contact is a resource having a http://www.semanticdesktop.org/ontologies/2007/03/22/nco#fullname
 * property. It can load any supported image format with the loadPicture slot.
 *
 * \author Adrien Bustany <madcat@mymadcat.com>
 */

class KDE_EXPORT PeopleTagWidget : public QWidget
{

	Q_OBJECT

public:
	/**
	 * Creates a PeopleTagWidget
	 */
	PeopleTagWidget(QWidget* parent = 0);

public Q_SLOTS:
	/**
	 * Loads a picture in the widget. The picture will be fitted in the widget's frame.
	 */
	void loadPicture(const QString& filename);

	/**
	 * Tells the widget to save its current regions into Nepomuk <br>
	 * The %saved signal will be emitted when the data is saved.
	 */
	void save();

signals:
	/**
	 * Emitted when the %save function returns
	 */
	void saved();

private Q_SLOTS:
	void newMarquee(Marquee* m);
	void marqueeSelected(Marquee* m);
	void peopleSelected(const QItemSelection& item);
	void addedPeopleSelected(const QItemSelection& item);
	void removeLinkedPeople();
	void modelReloading();
	void modelReloaded();
	void zoomScene();
	void addRegions(const QList<Soprano::BindingSet>& regions);
	void nepomukSynced();
	
protected:
	void showEvent(QShowEvent* event);
	void resizeEvent(QResizeEvent* event);

private:
	Ui::Interface*			m_gui;
	QString					m_picturePath;
	ImageMarquee*			m_imageScene;
	PeopleModel*			m_peopleModel;
	FilterModel*			m_filterModel;
	Marquee*				m_currentMarquee;
	LinkedPeopleModel*		m_linkedPeopleModel;
	QItemSelectionModel*	m_peopleSelection;
	QItemSelectionModel*	m_addedPeopleSelection;
	OtherPersonDialog*		m_otherPersonDialog;
	QMatrix					originalMatrix;
	NepomukProxy*			m_nepomuk;
};

} // End namespace Nepomuk

#endif
