/*
   Copyright (c) 2009 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef _NEPOMUK_RESOURCE_EDITOR_H_
#define _NEPOMUK_RESOURCE_EDITOR_H_

#include <QtGui/QWidget>
#include <QtCore/QList>

#include "nepomukannotation_export.h"

class KJob;

namespace Nepomuk {

    class Resource;
    class AnnotationModel;
    class Annotation;

    class NEPOMUKANNOTATION_EXPORT ResourceEditor : public QWidget
    {
        Q_OBJECT

    public:
        ResourceEditor( QWidget* parent = 0 );
        ~ResourceEditor();

        Resource resource() const;

        Nepomuk::AnnotationModel* annotationSuggestionModel() const;

        bool eventFilter( QObject* obj, QEvent* event );

    Q_SIGNALS:
        /**
         * Emitted if any annotation has been added or removed or changed.
         */
        void annotationsChanged();

    public Q_SLOTS:
        /**
         * The title displaying the resource's generic label (Nepomuk::Resource::genericLabel())
         * is optional. By default it is shown but can be disabled using this method.
         *
         * \param visible If \p true the title label will be visible, otherwise it will be hidden.
         */
        void setTitleVisible( bool visible );

        /**
         * Set the resource to annotate.
         *
         * \param res The resource for which annotations are to be displayed and created.
         *        It is recommended to only use pimo things here (i.e. use Resource::pimoThing())
         * \param content Optional full text content to be analysed for annotation suggestions
         *        If not set the resource's nie:plainTextContent is used. If that is empty, too, and
         *        the resource is an existing file, Strigi is used to extract the full text content.
         *        This is useful for resources that do not exist yet in the database.
         * \param manualAnnotations If set no plugins will be used to create annotations
         */
        void setResource( const Nepomuk::Resource& res,
                          const QString& content = QString(),
                          const QList<Nepomuk::Annotation*>& manualAnnotations = QList<Nepomuk::Annotation*>() );

    private:
        class Private;
        Private* const d;

        Q_PRIVATE_SLOT( d, void _k_ratingChanged( int ) )
        Q_PRIVATE_SLOT( d, void _k_labelChanged(bool) )
        Q_PRIVATE_SLOT( d, void _k_descriptionChanged(bool) )
        Q_PRIVATE_SLOT( d, void _k_slotDataChanged() )
        Q_PRIVATE_SLOT( d, void _k_annotationSuggestionModelChanged() )
        Q_PRIVATE_SLOT( d, void _k_resourceEditRequested( const Nepomuk::Resource& res ) )
        Q_PRIVATE_SLOT( d, void _k_openNepomukBrowser() )
        Q_PRIVATE_SLOT( d, void _k_annotationWidgetToggled( bool ) )
    };
}

#endif
