/*
   This file is part of the Nepomuk KDE project.
   Copyright (C) 2007 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
 */

#ifndef _NEPOMUK_RESOURCE_GUI_ITEM_FACTORY_H_
#define _NEPOMUK_RESOURCE_GUI_ITEM_FACTORY_H_

#include <nepomuk/nepomuk_export.h>

#include <QtCore/QObject>
#include <QtCore/QUrl>

namespace Nepomuk {

    class AbstractResourceGuiItem;

    class NEPOMUK_EXPORT ResourceGuiItemFactory : public QObject
    {
        Q_OBJECT

    public:
        /**
         * Create a new ResourceGuiItemFactory.
         */
        ResourceGuiItemFactory( QObject* parent = 0 );

        /**
         * Destructor.
         * Cleans the plugin cache.
         */
        ~ResourceGuiItemFactory();

        /**
         * This method never returns 0 but uses GenericResourceGuiItem as a fallback.
         * Gui items are cached. Thus, the same gui item might be returned multiple times.
         * 
         * The factory keeps track of deleted gui items. Thus, deleting the returned values
         * is ok but not necessary.
         */
        AbstractResourceGuiItem* guiItemForType( const QUrl& type );

        /**
         * This method never returns 0 but uses GenericResourceGuiItem as a fallback.
         */
        AbstractResourceGuiItem* guiItemForResource( const QUrl& resource );

        /**
         * This method never returns 0 but uses GenericResourceGuiItem as a fallback.
         */
//        AbstractResourceGuiItem* guiItemForMimeType( const QString& mimeType );

    private Q_SLOTS:
        void slotGuiItemDestroyed( QObject* );

    private:
        class Private;
        Private* const d;
    };
}

#endif
