/*
   This file is part of the Nepomuk KDE project.
   Copyright (C) 2010 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) version 3, or any
   later version accepted by the membership of KDE e.V. (or its
   successor approved by the membership of KDE e.V.), which shall
   act as a proxy defined in Section 6 of version 3 of the license.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _NEPOMUK_RESOURCE_NAVIGATOR_H_
#define _NEPOMUK_RESOURCE_NAVIGATOR_H_

#include "nepomuk_export.h"

#include <QtGui/QWidget>

#include <Nepomuk/Resource>
#include <Nepomuk/Query/Term>
#include <Nepomuk/Types/Property>


namespace Nepomuk {

    class ResourceNavigatorPrivate;

    class NEPOMUK_EXPORT ResourceNavigator : public QWidget
    {
        Q_OBJECT

    public:
        ResourceNavigator( QWidget* parent = 0 );
        ~ResourceNavigator();

        void setTopLevelType( const Types::Class& );
        void setParentRelationProperty( const Types::Property& prop );
        void setAllowResourceCreation( bool enabled );

        Resource currentResource() const;

    public Q_SLOTS:
        void setResource( const Nepomuk::Resource& res );

    Q_SIGNALS:
        void resourceChanged( const Nepomuk::Resource& res );

    private:
        ResourceNavigatorPrivate* const d;

        Q_PRIVATE_SLOT( d, void _k_resourceActivated( Nepomuk::NavigatorButton* button, const Nepomuk::Resource& res ) )
        Q_PRIVATE_SLOT( d, void _k_resourceButtonClicked() )

        friend class ResourceNavigatorPrivate;
    };
}

#endif
