/*
   This file is part of the Nepomuk KDE project.
   Copyright (C) 2009 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) version 3, or any
   later version accepted by the membership of KDE e.V. (or its
   successor approved by the membership of KDE e.V.), which shall
   act as a proxy defined in Section 6 of version 3 of the license.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef _NEPOMUK_TASK_MODEL_H_
#define _NEPOMUK_TASK_MODEL_H_

#include "resourcemodel.h"
#include "nepomuktasks_export.h"

class QMimeData;

namespace Nepomuk {
    class NEPOMUKTASKS_EXPORT TaskModel : public ResourceModel
    {
        Q_OBJECT

    public:
        TaskModel( QObject* parent = 0 );
        ~TaskModel();

        enum TaskRoles {
            /// QUrl referring to the state
            TaskStateRole = 3546869,
            /// QDateTime
            TaskDueDateRole = 234768,
            /// QUrl referring to the priority
            TaskPriorityRole = 78998,
            /// int value referring to the priority (-1 - low, 0 - medium, 1 - high)
            TaskPriorityNumRole = 7899834
            /// int between 0 and 100 (%)
//            TaskProgressRole = 378468
        };

        QUrl resourceForIndex( const QModelIndex& index ) const;
        QModelIndex indexForResource( const QUrl& uri ) const;

        Qt::ItemFlags flags( const QModelIndex& index ) const;
        QVariant data( const QModelIndex& index, int role = Qt::DisplayRole ) const;
        QModelIndex parent( const QModelIndex& index ) const;
        QModelIndex index( int row, int column, const QModelIndex& parent ) const;
        int rowCount(const QModelIndex&) const;
        int columnCount(const QModelIndex&) const;
        QVariant headerData( int section, Qt::Orientation orientation, int role = Qt::DisplayRole ) const;
        bool setData( const QModelIndex& index, const QVariant& value, int role = Qt::EditRole );

        QStringList mimeTypes() const;
        QMimeData* mimeData( const QModelIndexList& indexes ) const;
        bool dropMimeData( const QMimeData* data, Qt::DropAction action, int row, int column, const QModelIndex& parent );

    private:
        class Private;
        Private* const d;

        class TaskNode;
        class RootTaskNode;
        friend class TaskNode;

        Q_PRIVATE_SLOT( d, void _k_dataChanged() )
    };
}

#endif
