/*  This file is part of the KDE semantic clipboard
    Copyright (C) 2008 Tobias Wolf <twolf@access.unizh.ch>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
    Boston, MA 02110-1301, USA.
*/

#ifndef _SEMCLIP_GRAPHTRANSLATION_H_
#define _SEMCLIP_GRAPHTRANSLATION_H_

#include <QtCore/QSet>

class QString;
class QUrl;

namespace Soprano
{
    class Model;
}

namespace SemClip
{

    /**
     * \class GraphTranslation graphtranslation.h <semclip/graphtranslation.h>
     *
     * \brief Abstract base class for graph translation services.
     *
     * GraphTranslation defines the interface for graph translation services.
     * It consists of a single translate function, which takes a RDF graph
     * (either in the form of a RDF/XML serialization or a Soprano model) and
     * a set of target ontology URIs as parameters.
     *
     * For each supplied target ontology, a translation of the original graph
     * to that ontology is attempted. The successful translations are merged
     * into the original graph, in other words the supplied Soprano model is
     * augmented, or the supplied serialization replaced with one corresponding
     * to the merged graph.
     *
     * \author Tobias Wolf <twolf@access.unizh.ch>
     */
    class GraphTranslation
    {
    public:
        virtual ~GraphTranslation()
        {
        }

        virtual void translate( Soprano::Model* model, const QSet< QUrl >& targetOntologies ) = 0;

        virtual void translate( Soprano::Model* model, const QUrl& targetOntology ) = 0;

        virtual void translate( QString& serialization, const QSet< QUrl >& targetOntologies ) = 0;

        virtual void translate( QString& serialization, const QUrl& targetOntology ) = 0;
    };

}

#endif
